@@ -57,6 +57,7 @@ class Three(object):
         self.format = keywords['format'] or 'json'
         self.jurisdiction = keywords['jurisdiction']
         self.proxy = keywords['proxy']
+        self.discovery_url = keywords['discovery'] or None
 
     def _configure_endpoint(self, endpoint):
         """Configure the endpoint with a schema and end slash."""
@@ -151,6 +152,9 @@ class Three(object):
         """
         if url:
             data = requests.get(url).content
+        elif self.discovery_url:
+            # Spec calls for discovery always allowing JSON
+            data = requests.get(self.discovery_url).json
         else:
             data = self.get('discovery')
         return data
